@@ -193,7 +193,6 @@ function getJupyterHubUsername(): { username: string, fromJupyterHub: boolean }
   }
 
   // Not in a JupyterHub environment or username not found
-  console.log('No JupyterHub username found, using default');
   return { username: "VoittaDefaultUser", fromJupyterHub: false };
 }
 
@@ -416,7 +415,6 @@ export class ChatWidget extends Widget {
 
   async tool_say(args: any) {
     if ((typeof args["name"] != "string") || (typeof args["name"] == undefined)) {
-      console.log(args);
       return;
     }
 
@@ -495,7 +493,6 @@ export class ChatWidget extends Widget {
       const existingSettings = localStorage.getItem('escobar-settings');
       if (existingSettings) {
         localStorage.removeItem('escobar-settings');
-        console.log('🧹 CLEANUP: Removed legacy localStorage settings');
       }
     } catch (error) {
       console.warn('🧹 CLEANUP: Failed to clean localStorage:', error);
@@ -526,9 +523,6 @@ export class ChatWidget extends Widget {
 
       // If JupyterHub username detected and different from stored settings
       if (currentUsername !== 'User' && currentUsername !== storedUsername && currentUsername.includes('@')) {
-        console.log('🔧 AUTO-SAVE: Detected JupyterHub username:', currentUsername);
-        console.log('🔧 AUTO-SAVE: Current stored username:', storedUsername);
-
         // Auto-save the detected JupyterHub username
         await this.settingsManager.updateLocalSetting('username', currentUsername);
 
@@ -536,12 +530,6 @@ export class ChatWidget extends Widget {
         const updatedSettings = this.settingsManager.getCompleteSettings();
         (window as any).escobarCurrentSettings = updatedSettings;
         (window as any).escobarUsername = currentUsername;
-
-        console.log('🔧 AUTO-SAVE: Updated username in settings from JupyterHub:', currentUsername);
-      } else {
-        console.log('🔧 AUTO-SAVE: No JupyterHub username update needed');
-        console.log('🔧 AUTO-SAVE: Current username:', currentUsername);
-        console.log('🔧 AUTO-SAVE: Stored username:', storedUsername);
       }
     } catch (error) {
       console.error('🔧 AUTO-SAVE: Failed to auto-save JupyterHub username:', error);
@@ -552,8 +540,6 @@ export class ChatWidget extends Widget {
    * Handle settings changes from the SettingsManager
    */
   private onSettingsChanged(settings: IChatSettings): void {
-    console.log('🔧 SETTINGS: Settings change detected');
-
     // Update message handler with new settings
     const currentUsername = getUserName(this.settingsManager);
     this.messageHandler.updateSettings(
@@ -569,8 +555,6 @@ export class ChatWidget extends Widget {
     // Update global settings object
     (window as any).escobarCurrentSettings = settings;
     (window as any).escobarUsername = currentUsername;
-
-    console.log('🔧 SETTINGS: Updated username to:', currentUsername);
   }
 
   /**
@@ -617,8 +601,6 @@ export class ChatWidget extends Widget {
     // Update global variable
     (window as any).escobarUsername = currentUsername;
 
-    console.log('🔧 INIT: Updated username to:', currentUsername);
-
     registerFunction('handleResponse', false, this.handlePythonResponse.bind(this));
     registerFunction('say', false, this.say.bind(this));
     registerFunction('tool_say', false, this.tool_say.bind(this));
@@ -662,7 +644,6 @@ export class ChatWidget extends Widget {
       // Extract available models from the response
       if (listChatsResponse && listChatsResponse.value && listChatsResponse.value.models) {
         this.availableModels = listChatsResponse.value.models;
-        console.log('📋 MODELS: Received', this.availableModels.length, 'models from server');
 
         // Update the global models object for settings page
         (window as any).escobarAvailableModels = this.availableModels;
@@ -675,7 +656,6 @@ export class ChatWidget extends Widget {
         // Update the model dropdown with the loaded models
         this.updateModelDropdown();
       } else {
-        console.log('📋 MODELS: No models received from server');
         this.availableModels = [];
         (window as any).escobarAvailableModels = this.availableModels;
 
